=== modified file 'Makefile.am'
--- Makefile.am	2009-08-07 19:45:29 +0000
+++ Makefile.am	2009-09-22 22:19:58 +0000
@@ -146,7 +146,6 @@
 		mysys/mf_sort.cc \
 		mysys/mf_tempfile.cc \
 		mysys/mf_wcomp.cc \
-		mysys/mulalloc.cc \
 		mysys/my_access.cc \
 		mysys/my_alloc.cc \
 		mysys/my_bit.cc \

=== modified file 'drizzled/Makefile.am'
--- drizzled/Makefile.am	2009-09-21 23:40:18 +0000
+++ drizzled/Makefile.am	2009-09-22 22:19:58 +0000
@@ -289,6 +289,7 @@
 		lock.h \
 		logging.h \
 		lookup_symbol.h \
+		memory/multi_malloc.h \
 		my_decimal.h\
 		my_var.h \
 		name_resolution_context.h \
@@ -644,6 +645,7 @@
 		lock.cc \
 		logging.cc \
 		lookup_symbol.cc \
+		memory/multi_malloc.cc \
 		my_decimal.cc \
 		name_resolution_context_state.cc \
 		natural_join_column.cc \

=== added directory 'drizzled/memory'
=== renamed file 'mysys/mulalloc.cc' => 'drizzled/memory/multi_malloc.cc'
--- mysys/mulalloc.cc	2009-04-17 21:01:47 +0000
+++ drizzled/memory/multi_malloc.cc	2009-09-22 22:19:58 +0000
@@ -13,11 +13,18 @@
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
 
-#include "mysys/mysys_priv.h"
+#include "drizzled/global.h"
+
 #include <stdarg.h>
 #include <string.h>
 #include <stdlib.h>
 
+#include "drizzled/memory/multi_malloc.h"
+
+namespace drizzled
+{
+namespace memory
+{
 /*
   Malloc many pointers at the same time
   Only ptr1 can be free'd, and doing this will free all
@@ -25,42 +32,50 @@
   memory area.
 
   SYNOPSIS
-    my_multi_malloc()
-      myFlags              Flags
+    multi_malloc()
+      zerofill             Whether or not to fill with 0
 	ptr1, length1      Multiple arguments terminated by null ptr
 	ptr2, length2      ...
         ...
 	NULL
 */
 
-void* my_multi_malloc(myf myFlags, ...)
+void* multi_malloc(bool zerofill, ...)
 {
   va_list args;
-  char **ptr,*start,*res;
+  void **ptr, *start;
+  char *res;
   size_t tot_length,length;
 
-  va_start(args,myFlags);
+  va_start(args, zerofill);
   tot_length=0;
-  while ((ptr=va_arg(args, char **)))
+  while ((ptr=va_arg(args, void **)))
   {
-    length=va_arg(args,uint);
+    /*
+     * This must be unsigned int, not size_t.
+     * Otherwise, everything breaks.
+     */
+    length=va_arg(args, unsigned int);
     tot_length+=ALIGN_SIZE(length);
   }
   va_end(args);
 
-  if (!(start=(char *) malloc(tot_length)))
+  if (!(start= malloc(tot_length)))
     return(0); /* purecov: inspected */
-  if (myFlags & MY_ZEROFILL)
+  if (zerofill)
     memset(start, 0, tot_length);
 
-  va_start(args,myFlags);
-  res=start;
-  while ((ptr=va_arg(args, char **)))
+  va_start(args, zerofill);
+  res=reinterpret_cast<char *>(start);
+  while ((ptr=va_arg(args, void **)))
   {
     *ptr=res;
     length=va_arg(args,uint);
-    res+=ALIGN_SIZE(length);
+    res+= ALIGN_SIZE(length);
   }
   va_end(args);
-  return((void*) start);
+  return start;
 }
+
+} /* namespace memory */
+} /* namespace drizzled */

=== added file 'drizzled/memory/multi_malloc.h'
--- drizzled/memory/multi_malloc.h	1970-01-01 00:00:00 +0000
+++ drizzled/memory/multi_malloc.h	2009-09-22 22:19:58 +0000
@@ -0,0 +1,32 @@
+/* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2008 Sun Microsystems
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; version 2 of the License.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef DRIZZLED_ALLOCATOR_MULTI_MALLOC_H
+#define DRIZZLED_ALLOCATOR_MULTI_MALLOC_H
+
+namespace drizzled
+{
+namespace memory
+{
+void* multi_malloc(bool zerofill, ...) __attribute__((malloc));
+} /* namespace allocator */
+} /* namespace memory */
+
+#endif /* DRIZZLED_ALLOCATOR_MULTI_MALLOC_H */
+

=== modified file 'drizzled/opt_range.cc'
--- drizzled/opt_range.cc	2009-08-20 20:29:18 +0000
+++ drizzled/opt_range.cc	2009-09-22 22:19:58 +0000
@@ -118,7 +118,10 @@
 #include <vector>
 #include <algorithm>
 
+#include "drizzled/memory/multi_malloc.h"
+
 using namespace std;
+using namespace drizzled;
 
 #define HA_END_SPACE_KEY 0
 
@@ -7147,7 +7150,7 @@
   if (mrr_buf_size && !mrr_buf_desc)
   {
     buf_size= mrr_buf_size;
-    while (buf_size && !my_multi_malloc(MYF(MY_WME),
+    while (buf_size && ! memory::multi_malloc(false,
                                         &mrr_buf_desc, sizeof(*mrr_buf_desc),
                                         &mrange_buff, buf_size,
                                         NULL))

=== modified file 'drizzled/sql_base.cc'
--- drizzled/sql_base.cc	2009-08-20 20:29:18 +0000
+++ drizzled/sql_base.cc	2009-09-22 22:19:58 +0000
@@ -16,8 +16,6 @@
 
 /* Basic functions needed by many modules */
 #include <drizzled/server_includes.h>
-#include <drizzled/field/timestamp.h>
-#include <drizzled/field/null.h>
 #include <assert.h>
 
 #include <signal.h>
@@ -46,6 +44,9 @@
 #include <drizzled/lock.h>
 #include <drizzled/slot/listen.h>
 #include <mysys/cached_directory.h>
+#include <drizzled/field/timestamp.h>
+#include <drizzled/field/null.h>
+#include "drizzled/memory/multi_malloc.h"
 
 using namespace std;
 using namespace drizzled;
@@ -984,14 +985,14 @@
 
   /*
     Create a table entry with the right key and with an old refresh version
-    Note that we must use my_multi_malloc() here as this is freed by the
+    Note that we must use multi_malloc() here as this is freed by the
     table cache
   */
-  if (!my_multi_malloc(MYF(MY_WME | MY_ZEROFILL),
-                       &table, sizeof(*table),
-                       &share, sizeof(*share),
-                       &key_buff, key_length,
-                       NULL))
+  if (! memory::multi_malloc(true,
+                             &table, sizeof(*table),
+                             &share, sizeof(*share),
+                             &key_buff, key_length,
+                             NULL))
     return NULL;
 
   table->s= share;

=== modified file 'drizzled/sql_select.cc'
--- drizzled/sql_select.cc	2009-09-16 20:58:28 +0000
+++ drizzled/sql_select.cc	2009-09-22 22:19:58 +0000
@@ -23,6 +23,12 @@
   @{
 */
 #include "drizzled/server_includes.h"
+
+#include <string>
+#include <iostream>
+#include <algorithm>
+#include <vector>
+
 #include "drizzled/sql_select.h" /* include join.h */
 #include "drizzled/table_map_iterator.h"
 
@@ -45,16 +51,13 @@
 #include "drizzled/lock.h"
 #include "drizzled/item/outer_ref.h"
 #include "drizzled/index_hint.h"
-
-#include <drizzled/sql_union.h>
-#include <drizzled/optimizer/key_field.h>
-#include <drizzled/optimizer/position.h>
-#include <drizzled/optimizer/sargable_param.h>
-
-#include <string>
-#include <iostream>
-#include <algorithm>
-#include <vector>
+#include "drizzled/memory/multi_malloc.h"
+
+#include "drizzled/sql_union.h"
+#include "drizzled/optimizer/key_field.h"
+#include "drizzled/optimizer/position.h"
+#include "drizzled/optimizer/sargable_param.h"
+
 
 using namespace std;
 using namespace drizzled;
@@ -5412,7 +5415,7 @@
   uint32_t *field_lengths,*field_length;
   HASH hash;
 
-  if (!my_multi_malloc(MYF(MY_WME),
+  if (! memory::multi_malloc(false,
 		       &key_buffer,
 		       (uint32_t) ((key_length + extra_length) *
 			       (long) file->stats.records),

=== modified file 'mysys/my_bit.h'
--- mysys/my_bit.h	2009-02-21 00:18:15 +0000
+++ mysys/my_bit.h	2009-09-22 22:19:58 +0000
@@ -1,3 +1,26 @@
+/* - mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2008, 2009 Sun Microsystems
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef MYSYS_MY_BIT_H
+#define MYSYS_MY_BIT_H
+
 /*
   Some useful bit functions
 */
@@ -96,3 +119,4 @@
 }
 #endif
 
+#endif /* MYSYS_MY_BIT_H */

=== modified file 'mysys/my_sys.h'
--- mysys/my_sys.h	2009-07-17 23:20:36 +0000
+++ mysys/my_sys.h	2009-09-22 22:19:58 +0000
@@ -64,7 +64,6 @@
 #define MY_HOLD_ORIGINAL_MODES 128  /* my_copy() holds to file modes */
 #define MY_REDEL_MAKE_BACKUP 256
 #define MY_DONT_WAIT	64	/* my_lock() don't wait if can't lock */
-#define MY_ZEROFILL	32	/* my_multi_malloc(), fill array with zero */
 #define MY_DONT_OVERWRITE_FILE 1024	/* my_copy: Don't overwrite file */
 #define MY_THREADSAFE 2048      /* my_seek(): lock fd mutex */
 
@@ -298,7 +297,6 @@
 extern int my_rename(const char *from,const char *to,myf MyFlags);
 extern size_t my_write(File Filedes,const unsigned char *Buffer,size_t Count,
 		     myf MyFlags);
-extern void * my_multi_malloc (myf MyFlags, ...);
 extern int _sanity(const char *sFile, uint32_t uLine);
 
 #define my_access access

=== modified file 'plugin/csv/ha_tina.cc'
--- plugin/csv/ha_tina.cc	2009-08-05 09:29:04 +0000
+++ plugin/csv/ha_tina.cc	2009-09-22 22:19:58 +0000
@@ -47,6 +47,7 @@
 #include <drizzled/error.h>
 #include <drizzled/table.h>
 #include <drizzled/session.h>
+#include "drizzled/memory/multi_malloc.h"
 
 #include "ha_tina.h"
 
@@ -185,7 +186,7 @@
                                         (unsigned char*) table_name,
                                        length)))
   {
-    if (!my_multi_malloc(MYF(MY_WME | MY_ZEROFILL),
+    if (!drizzled::memory::multi_malloc(true,
                          &share, sizeof(*share),
                          &tmp_name, length+1,
                          NULL))

=== modified file 'plugin/innobase/handler/ha_innodb.cc'
--- plugin/innobase/handler/ha_innodb.cc	2009-08-20 21:45:52 +0000
+++ plugin/innobase/handler/ha_innodb.cc	2009-09-22 22:19:58 +0000
@@ -51,6 +51,7 @@
 #include <drizzled/field/timestamp.h>
 #include <drizzled/plugin/storage_engine.h>
 #include <drizzled/info_schema.h>
+#include "drizzled/memory/multi_malloc.h"
 
 /* Include necessary InnoDB headers */
 extern "C" {
@@ -2594,7 +2595,7 @@
 				table->s->stored_rec_length
 				+ table->s->max_key_length
 				+ MAX_REF_PARTS * 3;
-	if (!(unsigned char*) my_multi_malloc(MYF(MY_WME),
+	if (!(unsigned char*) drizzled::memory::multi_malloc(false,
 			&upd_buff, upd_and_key_val_buff_len,
 			&key_val_buff, upd_and_key_val_buff_len,
 			NULL)) {

=== modified file 'plugin/myisam/ha_myisam.cc'
--- plugin/myisam/ha_myisam.cc	2009-09-14 20:02:41 +0000
+++ plugin/myisam/ha_myisam.cc	2009-09-22 22:19:58 +0000
@@ -20,13 +20,16 @@
 #include "myisampack.h"
 #include "ha_myisam.h"
 #include "myisamdef.h"
-#include <drizzled/util/test.h>
-#include <drizzled/error.h>
-#include <drizzled/errmsg_print.h>
-#include <drizzled/gettext.h>
-#include <drizzled/session.h>
-#include <drizzled/table.h>
-#include <drizzled/field/timestamp.h>
+#include "mysys/my_bit.h"
+#include "drizzled/util/test.h"
+#include "drizzled/error.h"
+#include "drizzled/errmsg_print.h"
+#include "drizzled/gettext.h"
+#include "drizzled/session.h"
+#include "drizzled/plugin/protocol.h"
+#include "drizzled/table.h"
+#include "drizzled/field/timestamp.h"
+#include "drizzled/memory/multi_malloc.h"
 
 #include <string>
 #include <algorithm>
@@ -116,7 +119,7 @@
     table conformance in merge engine.
 
     The caller needs to free *recinfo_out after use. Since *recinfo_out
-    and *keydef_out are allocated with a my_multi_malloc, *keydef_out
+    and *keydef_out are allocated with a multi_malloc, *keydef_out
     is freed automatically when *recinfo_out is freed.
 
   RETURN VALUE
@@ -136,11 +139,10 @@
   HA_KEYSEG *keyseg;
   TableShare *share= table_arg->s;
   uint32_t options= share->db_options_in_use;
-  if (!(my_multi_malloc(MYF(MY_WME),
+  if (!(drizzled::memory::multi_malloc(false,
           recinfo_out, (share->fields * 2 + 2) * sizeof(MI_COLUMNDEF),
           keydef_out, share->keys * sizeof(MI_KEYDEF),
-          &keyseg,
-          (share->key_parts + share->keys) * sizeof(HA_KEYSEG),
+          &keyseg, (share->key_parts + share->keys) * sizeof(HA_KEYSEG),
           NULL)))
     return(HA_ERR_OUT_OF_MEM); /* purecov: inspected */
   keydef= *keydef_out;
@@ -565,7 +567,7 @@
   this->close();
  end:
   /*
-    Both recinfo and keydef are allocated by my_multi_malloc(), thus only
+    Both recinfo and keydef are allocated by multi_malloc(), thus only
     recinfo must be freed.
   */
   if (recinfo)

=== modified file 'plugin/myisam/mi_open.cc'
--- plugin/myisam/mi_open.cc	2009-08-17 20:38:45 +0000
+++ plugin/myisam/mi_open.cc	2009-09-22 22:19:58 +0000
@@ -16,13 +16,16 @@
 /* open a isam-database */
 
 #include "myisamdef.h"
-#include <mystrings/m_ctype.h>
-#include <mystrings/m_string.h>
-#include <drizzled/util/test.h>
 
 #include <string.h>
 #include <algorithm>
 
+#include "mystrings/m_ctype.h"
+#include "mystrings/m_string.h"
+#include "drizzled/util/test.h"
+#include "drizzled/memory/multi_malloc.h"
+
+
 using namespace std;
 
 static void setup_key_functions(MI_KEYDEF *keyinfo);
@@ -222,26 +225,24 @@
     /* Add space for node pointer */
     share->base.max_key_length+= share->base.key_reflength;
 
-    if (!my_multi_malloc(MY_WME,
-			 &share,sizeof(*share),
-			 &share->state.rec_per_key_part,sizeof(long)*key_parts,
-			 &share->keyinfo,keys*sizeof(MI_KEYDEF),
-			 &share->uniqueinfo,uniques*sizeof(MI_UNIQUEDEF),
-			 &share->keyparts,
-			 (key_parts+unique_key_parts+keys+uniques) *
-			 sizeof(HA_KEYSEG),
-			 &share->rec,
-			 (share->base.fields+1)*sizeof(MI_COLUMNDEF),
-			 &share->blobs,sizeof(MI_BLOB)*share->base.blobs,
-			 &share->unique_file_name,strlen(name_buff)+1,
-			 &share->index_file_name,strlen(index_name)+1,
-			 &share->data_file_name,strlen(data_name)+1,
-			 &share->state.key_root,keys*sizeof(my_off_t),
-			 &share->state.key_del,
-			 (share->state.header.max_block_size_index*sizeof(my_off_t)),
-			 &share->key_root_lock,sizeof(pthread_rwlock_t)*keys,
-			 &share->mmap_lock,sizeof(pthread_rwlock_t),
-			 NULL))
+    if (!drizzled::memory::multi_malloc(false,
+           &share,sizeof(*share),
+           &share->state.rec_per_key_part,sizeof(long)*key_parts,
+           &share->keyinfo,keys*sizeof(MI_KEYDEF),
+           &share->uniqueinfo,uniques*sizeof(MI_UNIQUEDEF),
+           &share->keyparts,
+           (key_parts+unique_key_parts+keys+uniques) * sizeof(HA_KEYSEG),
+           &share->rec, (share->base.fields+1)*sizeof(MI_COLUMNDEF),
+           &share->blobs,sizeof(MI_BLOB)*share->base.blobs,
+           &share->unique_file_name,strlen(name_buff)+1,
+           &share->index_file_name,strlen(index_name)+1,
+           &share->data_file_name,strlen(data_name)+1,
+           &share->state.key_root,keys*sizeof(uint64_t),
+           &share->state.key_del,
+           (share->state.header.max_block_size_index*sizeof(uint64_t)),
+           &share->key_root_lock,sizeof(pthread_rwlock_t)*keys,
+           &share->mmap_lock,sizeof(pthread_rwlock_t),
+           NULL))
       goto err;
     errpos=4;
     *share=share_buff;
@@ -425,16 +426,16 @@
   }
 
   /* alloc and set up private structure parts */
-  if (!my_multi_malloc(MY_WME,
-		       &m_info,sizeof(MI_INFO),
-		       &info.blobs,sizeof(MI_BLOB)*share->base.blobs,
-		       &info.buff,(share->base.max_key_block_length*2+
-				   share->base.max_key_length),
-		       &info.lastkey,share->base.max_key_length*3+1,
-		       &info.first_mbr_key, share->base.max_key_length,
-		       &info.filename,strlen(name)+1,
-		       &info.rtree_recursion_state,have_rtree ? 1024 : 0,
-		       NULL))
+  if (!drizzled::memory::multi_malloc(MY_WME,
+         &m_info,sizeof(MI_INFO),
+         &info.blobs,sizeof(MI_BLOB)*share->base.blobs,
+         &info.buff,(share->base.max_key_block_length*2+
+                     share->base.max_key_length),
+         &info.lastkey,share->base.max_key_length*3+1,
+         &info.first_mbr_key, share->base.max_key_length,
+         &info.filename,strlen(name)+1,
+         &info.rtree_recursion_state,have_rtree ? 1024 : 0,
+         NULL))
     goto err;
   errpos=6;
 

